@@ -6,15 +6,15 @@ use strict;
 
 =head1 NAME
 
-WWW::Vimeo::Simple::Group - The great new WWW::Vimeo::Simple::Group!
+WWW::Vimeo::Simple::Group - Object-oriented Vimeo Simple API interface. Group requests.
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 SYNOPSIS
 
@@ -158,6 +158,14 @@ You can also look for information at:
 
 =over 4
 
+=item * TwitShell homepage
+
+L<http://alexlog.co.cc/projects/www-vimeo-simple>
+
+=item * Git repository
+
+L<http://github.com/AlexBio/WWW-Vimeo-Simple>
+
 =item * RT: CPAN's request tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-Vimeo-Simple>
