@@ -6,15 +6,15 @@ use strict;
 
 =head1 NAME
 
-WWW::Vimeo::Simple::User - Object-oriented Vimeo Simple API interface.
+WWW::Vimeo::Simple::User - Object-oriented Vimeo Simple API interface. User requests.
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 =head1 SYNOPSIS
@@ -268,6 +268,14 @@ You can also look for information at:
 
 =over 4
 
+=item * TwitShell homepage
+
+L<http://alexlog.co.cc/projects/www-vimeo-simple>
+
+=item * Git repository
+
+L<http://github.com/AlexBio/WWW-Vimeo-Simple>
+
 =item * RT: CPAN's request tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-Vimeo-Simple>
